@@ -40,7 +40,7 @@ pgf_with_latex = {                      # setup matplotlib to use latex for outp
     
     "axes.linewidth": 2,                
 
-    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
+    "legend.fontsize": 'small',               # Make the legend/label fonts a little smaller
 
     "xtick.labelsize": 16,
 
@@ -101,17 +101,20 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax.set_xlabel('Frequency [Thz]')
     ax.set_ylabel('DOS [kB T * ps]')
     
-    ax1 = ax.twiny()
-    ax1.set_xlabel('Frequency [cm$^{-1}$]')
-    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
-    ax1.set_xlim(-1*33.35641,25*33.35641)
-    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     ax.set_xlim(left=-1,right=25)
     ax.tick_params(axis='both', labelsize=16, width=2 , length=6, direction='in', right=True)
 
 
     graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), linewidth=1, c='red', label='freq from dispersion')
     plt.legend(handles=[graph3])
+    
+    ax1 = ax.twiny()
+    ax1.set_xlabel('Frequency [cm$^{-1}$]')
+    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
+    ax1.set_xlim(-1*33.35641,25*33.35641)
+    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
+    
+    
     plt.tight_layout()
     fig0.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'_spectrum.pdf')
 # =============================================================================
@@ -129,11 +132,6 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax.set_xlabel('Frequency [Thz]')
     ax.set_ylabel('DOS [kB T * ps]')
     
-    ax1 = ax.twiny()
-    ax1.set_xlabel('Frequency [cm$^{-1}$]')
-    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
-    ax1.set_xlim(-1*33.35641,25*33.35641)
-    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     ax.set_xlim(left=-1,right=25)
     ax.tick_params(axis='both', labelsize=16, width=2 , length=6, direction='in', right=True)
 
@@ -141,6 +139,13 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax.set_ylim(bottom=-.05*convolution.max(),top=convolution.max()*1.5)
     graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), linewidth=1, c='red', label='freq from dispersion')
     plt.legend(handles=[graph3, graph5])
+    
+    ax1 = ax.twiny()
+    ax1.set_xlabel('Frequency [cm$^{-1}$]')
+    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
+    ax1.set_xlim(-1*33.35641,25*33.35641)
+    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
+    
     plt.tight_layout()
     fig.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'.pdf')
 # =============================================================================
@@ -160,11 +165,6 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax.set_xlabel('Frequency [Thz]')
     ax.set_ylabel('DOS [kB T * ps]')
     
-    ax1 = ax.twiny()
-    ax1.set_xlabel('Frequency [cm$^{-1}$]')
-    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
-    ax1.set_xlim(-1*33.35641,25*33.35641)
-    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     ax.set_xlim(left=-1,right=25)
     ax.tick_params(axis='both', labelsize=16, width=2 , length=6, direction='in',right=True)
     
@@ -179,6 +179,14 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
         ax.axvspan(omega0-gamma/2, omega0+gamma/2, ymin=0, ymax=1, color='grey', alpha=0.2)
     graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), linewidth=1,  c='red', label='freq from dispersion')
     plt.legend(handles=[   graph3, graph4])
+    
+    ax1 = ax.twiny()
+    ax1.set_xlabel('Frequency [cm$^{-1}$]')
+    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
+    ax1.set_xlim(-1*33.35641,25*33.35641)
+    ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
+    
+    
     plt.tight_layout()
     fig1.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'_lorentzian.pdf')
 # =============================================================================
